<?php

namespace Drupal\gtfs\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\RevisionLogInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining GTFS Feed entities.
 *
 * @ingroup gtfs
 */
interface FeedInterface extends ContentEntityInterface, RevisionLogInterface, EntityChangedInterface, EntityOwnerInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the GTFS Feed name.
   *
   * @return string
   *   Name of the GTFS Feed.
   */
  public function getName();

  /**
   * Sets the GTFS Feed name.
   *
   * @param string $name
   *   The GTFS Feed name.
   *
   * @return \Drupal\gtfs\Entity\FeedInterface
   *   The called GTFS Feed entity.
   */
  public function setName($name);

  /**
   * Gets the GTFS Feed creation timestamp.
   *
   * @return int
   *   Creation timestamp of the GTFS Feed.
   */
  public function getCreatedTime();

  /**
   * Sets the GTFS Feed creation timestamp.
   *
   * @param int $timestamp
   *   The GTFS Feed creation timestamp.
   *
   * @return \Drupal\gtfs\Entity\FeedInterface
   *   The called GTFS Feed entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the GTFS Feed published status indicator.
   *
   * Unpublished GTFS Feed are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the GTFS Feed is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a GTFS Feed.
   *
   * @param bool $published
   *   TRUE to set this GTFS Feed to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\gtfs\Entity\FeedInterface
   *   The called GTFS Feed entity.
   */
  public function setPublished($published);

  /**
   * Gets the GTFS Feed revision creation timestamp.
   *
   * @return int
   *   The UNIX timestamp of when this revision was created.
   */
  public function getRevisionCreationTime();

  /**
   * Sets the GTFS Feed revision creation timestamp.
   *
   * @param int $timestamp
   *   The UNIX timestamp of when this revision was created.
   *
   * @return \Drupal\gtfs\Entity\FeedInterface
   *   The called GTFS Feed entity.
   */
  public function setRevisionCreationTime($timestamp);

  /**
   * Gets the GTFS Feed revision author.
   *
   * @return \Drupal\user\UserInterface
   *   The user entity for the revision author.
   */
  public function getRevisionUser();

  /**
   * Sets the GTFS Feed revision author.
   *
   * @param int $uid
   *   The user ID of the revision author.
   *
   * @return \Drupal\gtfs\Entity\FeedInterface
   *   The called GTFS Feed entity.
   */
  public function setRevisionUserId($uid);

}
