<?php

namespace Drupal\gtfs;

use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Language\LanguageInterface;
use Drupal\gtfs\Entity\FeedInterface;

/**
 * Defines the storage handler class for GTFS Feed entities.
 *
 * This extends the base storage class, adding required special handling for
 * GTFS Feed entities.
 *
 * @ingroup gtfs
 */
class FeedStorage extends SqlContentEntityStorage {

  /**
   * {@inheritdoc}
   */
  public function revisionIds(FeedInterface $entity) {
    return $this->database->query(
      'SELECT vid FROM {gtfs_feed_revision} WHERE id=:id ORDER BY vid',
      [':id' => $entity->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function userRevisionIds(AccountInterface $account) {
    return $this->database->query(
      'SELECT vid FROM {gtfs_feed_field_revision} WHERE uid = :uid ORDER BY vid',
      [':uid' => $account->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function countDefaultLanguageRevisions(FeedInterface $entity) {
    return $this->database->query('SELECT COUNT(*) FROM {gtfs_feed_field_revision} WHERE id = :id AND default_langcode = 1', [':id' => $entity->id()])
      ->fetchField();
  }

  /**
   * {@inheritdoc}
   */
  public function clearRevisionsLanguage(LanguageInterface $language) {
    return $this->database->update('gtfs_feed_revision')
      ->fields(['langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED])
      ->condition('langcode', $language->getId())
      ->execute();
  }

}
