<?php

namespace Drupal\gtfs\Plugin\rest\resource;

use Drupal;

/**
 * Provides GTFS agencies as a rest resource.
 *
 * @RestResource(
 *   id = "gtfs_agency_list_resource",
 *   label = @Translation("GTFS agencies REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/agencies"
 *   }
 * )
 */
class AgencyListResource extends GTFSResourceBase {

  public static $url = '/gtfs/api/v1/agencies';

  /**
   * Responds to agency GET requests.
   *
   * @return Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   *   The API response
   */
  public function get() {

    $meta = $this->initializeMeta();

    $storage = Drupal::entityTypeManager()->getStorage('gtfs_agency');

    $query = Drupal::database()->select('gtfs_agency_field_data', 'a')
      ->fields('a', ['id'])
      ->addTag('gtfs_agency_access');

    $meta['totalCount'] = (clone $query)->countQuery()->execute()->fetchColumn();

    // https://tools.ietf.org/html/rfc7231#section-6.3.5
    if (empty($meta['totalCount'])) {
      return new ResourceResponse([], $meta, 204);
    }

    $results = $query->range($meta['offset'], $meta['limit'])->execute()->fetchAll(\PDO::FETCH_COLUMN);

    // https://tools.ietf.org/html/rfc7231#section-6.3.6
    if (empty($results)) {
      return new ResourceResponse([], $meta, 205);
    }

    if (is_string($results)) {
      $results = [$results];
    }

    ResourceMeta::setPagerFromResults($meta, [
      'results' => $results,
      'url' => self::$url,
    ]);

    $data = array_map(function ($agency) {
      return $agency->toGTFSObject();
    }, array_values($storage->loadMultiple($results)));

    return new ResourceResponse($data, $meta);

  }

}
