<?php

namespace Drupal\gtfs\Plugin\rest\resource;

use Drupal\gtfs\Entity\Agency;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Provides a single GTFS agency as a rest resource.
 *
 * @RestResource(
 *   id = "gtfs_agency_resource",
 *   label = @Translation("GTFS agency REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/agencies/{agency_id}"
 *   }
 * )
 */
class AgencyResource extends GTFSResourceBase {

  public static $invalid_request_message = 'No agency was provided';

  public static $not_found_message = 'Agency with ID @agency_id was not found';

  /**
   * Responds to agency GET requests.
   *
   * @return \Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   */
  public function get($agency_id = NULL) {

    if (!$agency_id) {
      throw new BadRequestHttpException(t(static::$invalid_request_message));
    }

    $agency = Agency::getById($agency_id);

    if (!$agency) {
      throw new NotFoundHttpException(t(static::$not_found_message, ['@agency_id' => $agency_id]));
    }

    $meta = $this->initializeMeta();
    $meta['totalCount'] = $meta['dataCount'] = 1;
    $meta['links'] = array_merge($meta['links'], $agency->links());

    $data = $agency->toGTFSObject();

    return new ResourceResponse($data, $meta);
  }


}
