<?php

namespace Drupal\gtfs\Plugin\rest\resource;

use Drupal;
use Drupal\gtfs\Entity\Agency;

/**
 * Provides GTFS routes as a rest resource.
 *
 * @RestResource(
 *   id = "gtfs_route_list_resource",
 *   label = @Translation("GTFS routes REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/agencies/{agency_id}/routes"
 *   }
 * )
 */
class RouteListResource extends GTFSResourceBase {

  public static $url = '/gtfs/api/v1/agencies/{agency_id}/routes';

  /**
   * Responds to route GET requests.
   *
   * @return \Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   *   The response.
   */
  public function get($agency_id = NULL) {

    $agency = Agency::getById($agency_id);

    $meta = $this->initializeMeta();

    $storage = Drupal::entityTypeManager()->getStorage('gtfs_route');

    $meta['totalCount'] = (int) $agency->routeIds()->count()->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.5
    if (!$meta['totalCount']) {
      return new ResourceResponse([], $meta, 204);
    }

    $results = $agency->routeIds()
      ->range($meta['offset'], $meta['limit'])
      ->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.6
    if (empty($results)) {
      return new ResourceResponse([], $meta, 205);
    }

    if (is_string($results)) {
      $results = [$results];
    }

    ResourceMeta::setPagerFromResults($meta, [
      'results' => $results,
      'url' => str_replace('{agency_id}', $agency_id, self::$url),
    ]);

    $data = array_map(function ($route) {
      return $route->toGTFSObject();
    }, array_values($storage->loadMultiple($results)));

    return new ResourceResponse($data, $meta);
  }

}
