<?php

namespace Drupal\gtfs\Plugin\rest\resource;

use Drupal\gtfs\Entity\Agency;
use Drupal\gtfs\Entity\Route;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Provides a single GTFS route as a rest resource.
 *
 * @RestResource(
 *   id = "gtfs_route_resource",
 *   label = @Translation("GTFS route REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/agencies/{agency_id}/routes/{route_id}"
 *   }
 * )
 */
class RouteResource extends GTFSResourceBase {

  public static $invalidRequestMessage = 'No route was provided';

  public static $notFoundMessage = 'Route with ID @route_id was not found for agency with ID @agency_id';

  /**
   * Responds to route GET requests.
   *
   * @return \Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   */
  public function get($agency_id = NULL, $route_id = NULL) {

    $agency = Agency::getById($agency_id);

    if (!$route_id) {
      throw new BadRequestHttpException(t(static::$invalidRequestMessage));
    }

    $route = Route::getById($agency, $route_id);

    if (!$route) {
      throw new NotFoundHttpException(t(static::$notFoundMessage, ['@route_id' => $route_id, '@agency_id' => $agency->id()]));
    }

    $meta = $this->initializeMeta();
    $meta['totalCount'] = $meta['dataCount'] = 1;
    $meta['links'] = array_merge($meta['links'], $route->links());

    $data = $route->toGTFSObject();

    return new ResourceResponse($data, $meta);
  }

}
