<?php

namespace Drupal\gtfs\Plugin\rest\resource;

/**
 * Provides GTFS services as a rest resource
 *
 * @RestResource(
 *   id = "gtfs_service_list_resource",
 *   label = @Translation("GTFS services REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/services"
 *   }
 * )
 */
class ServiceListResource extends GTFSResourceBase {

  public static $url = '/gtfs/api/v1/services';

  /**
   * Responds to service GET requests
   * @return \Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   */
  public function get() {

    $meta = $this->initializeMeta();

    $storage = \Drupal::entityTypeManager()->getStorage('gtfs_service');

    $query = \Drupal::entityQuery('gtfs_service');

    $meta['totalCount'] = (int) (clone $query)->count()->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.5
    if(!$meta['totalCount']) return new ResourceResponse([], $meta, 204);

    $results = $query->range($meta['offset'], $meta['limit'])->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.6
    if(empty($results)) return new ResourceResponse([], $meta, 205);

    if(is_string($results)) $results = [$results];

    ResourceMeta::setPagerFromResults($meta, [
      'results' => $results,
      'url' => self::$url
    ]);

    $data = array_map(function ($service) {
      return $service->toGTFSObject();
    }, array_values($storage->loadMultiple($results)));

    return new ResourceResponse($data, $meta);
  }
}
