<?php

namespace Drupal\gtfs\Plugin\rest\resource;

use Drupal;

/**
 * Provides GTFS stops as a rest resource.
 *
 * @RestResource(
 *   id = "gtfs_stop_list_resource",
 *   label = @Translation("GTFS stops REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/stops"
 *   }
 * )
 */
class StopListResource extends GTFSResourceBase {

  public static $url = '/gtfs/api/v1/stops';

  /**
   * Responds to route GET requests.
   *
   * @return \Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   *   The response.
   */
  public function get() {

    $meta = $this->initializeMeta();

    $storage = Drupal::entityTypeManager()->getStorage('gtfs_stop');

    $query = Drupal::entityQuery('gtfs_stop')->addTag('gtfs_stop_access');

    $meta['totalCount'] = (int) $query->count()->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.5
    if (!$meta['totalCount']) {
      return new ResourceResponse([], $meta, 204);
    }

    $results = $query
      ->range($meta['offset'], $meta['limit'])
      ->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.6
    if (empty($results)) {
      return new ResourceResponse([], $meta, 205);
    }

    if (is_string($results)) {
      $results = [$results];
    }

    ResourceMeta::setPagerFromResults($meta, [
      'results' => $results,
      'url' => self::$url,
    ]);

    $data = array_map(function ($stop) {
      return $stop->toGTFSObject();
    }, array_values($storage->loadMultiple($results)));

    return new ResourceResponse($data, $meta);
  }

}
