<?php

namespace Drupal\gtfs\Plugin\rest\resource;

use Drupal\gtfs\Entity\Stop;
use Symfony\Component\HttpKernel\Exception\BadRequestHttpException;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Provides GTFS stops as a rest resource.
 *
 * @RestResource(
 *   id = "gtfs_stop_resource",
 *   label = @Translation("GTFS stop REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/stops/{stop_id}"
 *   }
 * )
 */
class StopResource extends GTFSResourceBase {

  public static $invalidRequestMessage = 'No stop was provided';

  public static $notFoundMessage = 'Stop with ID @stop_id was not found';

  /**
   * Responds to stop GET requests.
   *
   * @return \Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   */
  public function get($stop_id = NULL): ResourceResponse {
    if (!$stop_id) {
      throw new BadRequestHttpException(t(static::$invalidRequestMessage));
    }

    $stop = Stop::getById($stop_id);

    if (!$stop) {
      throw new NotFoundHttpException(t(static::$notFoundMessage, ['@stop_id' => $stop_id]));
    }

    $meta = $this->initializeMeta();
    $meta['totalCount'] = $meta['dataCount'] = 1;
    $meta['links'] = array_merge($meta['links'], $stop->links());

    $data = $stop->toGTFSObject();

    return new ResourceResponse($data, $meta);
  }

}
