<?php

namespace Drupal\gtfs\Plugin\rest\resource;

/**
 * Provides GTFS stop times as a rest resource
 *
 * @RestResource(
 *   id = "gtfs_stop_time_list_resource",
 *   label = @Translation("GTFS trip stop times REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/agencies/{agency_id}/routes/{route_id}/trips/{trip_id}/stopTimes"
 *   }
 * )
 */
class StopTimeListResource extends GTFSResourceBase {

  public static $url = '/gtfs/api/v1/agencies/{agency_id}/routes/{route_id}/trips/{trip_id}/stopTimes';

  /**
   * Responds to stop time GET requests
   * @return \Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   */
  public function get($agency_id = NULL, $route_id = NULL, $trip_id = NULL) {

    $agency = Agency::getById($agency_id);

    $route = Route::getById($agency, $route_id);

    $trip = Trip::getById($route, $trip_id);

    $meta = $this->initializeMeta();

    $storage = \Drupal::entityTypeManager()->getStorage('gtfs_stop_time');

    $query = \Drupal::entityQuery('gtfs_stop_time')->condition('trip_id', $trip->id())->condition('feed_reference__target_id', $agency->get('feed_reference')->target_id);

    $meta['totalCount'] = (int) (clone $query)->count()->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.5
    if(!$meta['totalCount']) return new ResourceResponse([], $meta, 204);

    $results = $query->range($meta['offset'], $meta['limit'])->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.6
    if(empty($results)) return new ResourceResponse([], $meta, 205);

    if(is_string($results)) $results = [$results];

    ResourceMeta::setPagerFromResults($meta, [
      'results' => $results,
      'url' => str_replace(['{agency_id}', '{route_id}', '{trip_id}'], [$agency_id, $route_id, $trip_id], self::$url)
    ]);

    $data = array_map(function ($stopTime) {
      return $stopTime->toGTFSObject();
    }, array_values($storage->loadMultiple($results)));

    return new ResourceResponse($data, $meta);
  }
}
