<?php

namespace Drupal\gtfs\Plugin\rest\resource;

use Drupal\gtfs\Entity\Agency;
use Drupal\gtfs\Entity\Route;

/**
 * Provides GTFS trips as a rest resource
 *
 * @RestResource(
 *   id = "gtfs_trip_list_resource",
 *   label = @Translation("GTFS route trips REST"),
 *   uri_paths = {
 *     "canonical" = "/gtfs/api/v1/agencies/{agency_id}/routes/{route_id}/trips"
 *   }
 * )
 */
class TripListResource extends GTFSResourceBase {

  public static $url = '/gtfs/api/v1/agencies/{agency_id}/routes/{route_id}/trips';

  /**
   * Responds to trip GET requests
   * @return \Drupal\gtfs\Plugin\rest\resource\ResourceResponse
   */
  public function get($agency_id = NULL, $route_id = NULL) {

    $agency = Agency::getById($agency_id);

    $route = Route::getById($agency, $route_id);

    $meta = $this->initializeMeta();

    $storage = \Drupal::entityTypeManager()->getStorage('gtfs_trip');

    $query = \Drupal::entityQuery('gtfs_trip')->condition('route_id', $route->id())->condition('feed_reference__target_id', $agency->get('feed_reference')->target_id);

    $meta['totalCount'] = (int) (clone $query)->count()->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.5
    if(!$meta['totalCount']) return new ResourceResponse([], $meta, 204);

    $results = $query->range($meta['offset'], $meta['limit'])->execute();

    // https://tools.ietf.org/html/rfc7231#section-6.3.6
    if(empty($results)) return new ResourceResponse([], $meta, 205);

    if(is_string($results)) $results = [$results];

    ResourceMeta::setPagerFromResults($meta, [
      'results' => $results,
      'url' => str_replace(['{agency_id}', '{route_id}'], [$agency_id, $route_id], self::$url)
    ]);

    $data = array_map(function ($trip) {
      return $trip->toGTFSObject();
    }, array_values($storage->loadMultiple($results)));

    return new ResourceResponse($data, $meta);
  }
}
